bliss: Computing automorphism groups and canonical forms of graphs
==================================================================

Description
-----------

bliss is an open source tool for computing automorphism groups and
canonical forms of graphs.

License
-------

LGPL3


Upstream Contact
----------------

Bliss is currently being maintained by Tommi Junttila at

https://users.aalto.fi/~tjunttil/bliss/index.html

Bliss used to be maintained by Tommi Junttila and Petteri Kaski up to version 0.73 at

http://www.tcs.tkk.fi/Software/bliss/index.html
